@@ -7,14 +7,14 @@ use strict;
 
 package POSIX::1003::FdIO;
 use vars '$VERSION';
-$VERSION = '0.95.1';
+$VERSION = '0.96';
 
 use base 'POSIX::1003::Module';
 
 # Blocks resp from unistd.h, limits.h, and stdio.h
 my (@constants, @seek, @mode);
 my @functions = qw/closefd creatfd dupfd dup2fd openfd pipefd
-  readfd seekfd writefd tellfd fdopen/;
+  readfd seekfd writefd tellfd truncfd fdopen/;
 
 our %EXPORT_TAGS =
  ( constants => \@constants
@@ -75,6 +75,7 @@ sub fdopen($$)
     $fh;
 }
 
+
 #------------------
 
 sub tellfd($)     {seekfd $_[0], 0, SEEK_CUR() }
